summaryrefslogtreecommitdiff
path: root/plugins/nvm/nvm.plugin.zsh
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/nvm/nvm.plugin.zsh')
-rw-r--r--plugins/nvm/nvm.plugin.zsh47
1 files changed, 37 insertions, 10 deletions
diff --git a/plugins/nvm/nvm.plugin.zsh b/plugins/nvm/nvm.plugin.zsh
index 1fb4d238b..ec583cc2d 100644
--- a/plugins/nvm/nvm.plugin.zsh
+++ b/plugins/nvm/nvm.plugin.zsh
@@ -16,14 +16,41 @@ fi
# Note: nvm is a function so we need to use `which`
which nvm &>/dev/null && return
-if (( $+NVM_LAZY )); then
- # Call nvm when first using nvm, node, npm, pnpm, yarn or $NVM_LAZY_CMD
- function nvm node npm pnpm yarn $NVM_LAZY_CMD {
- unfunction nvm node npm pnpm yarn $NVM_LAZY_CMD
- # Load nvm if it exists in $NVM_DIR
- [[ -f "$NVM_DIR/nvm.sh" ]] && source "$NVM_DIR/nvm.sh"
- "$0" "$@"
- }
+# TODO: 2022-11-11: Remove soft-deprecate options
+if (( ${+NVM_LAZY} + ${+NVM_LAZY_CMD} + ${+NVM_AUTOLOAD} )); then
+ # Get list of NVM_* variable settings defined
+ local -a used_vars
+ used_vars=(${(o)parameters[(I)NVM_(AUTOLOAD|LAZY|LAZY_CMD)]})
+ # Nicely print the list in the style `var1, var2 and var3`
+ echo "${fg[yellow]}[nvm plugin] Variable-style settings are deprecated. Instead of ${(j:, :)used_vars[1,-2]}${used_vars[-2]+ and }${used_vars[-1]}, use:\n"
+ if (( $+NVM_AUTOLOAD )); then
+ echo " zstyle ':omz:plugins:nvm' autoload true"
+ zstyle ':omz:plugins:nvm' autoload yes
+ fi
+ if (( $+NVM_LAZY )); then
+ echo " zstyle ':omz:plugins:nvm' lazy true"
+ zstyle ':omz:plugins:nvm' lazy yes
+ fi
+ if (( $+NVM_LAZY_CMD )); then
+ echo " zstyle ':omz:plugins:nvm' lazy-cmd $NVM_LAZY_CMD"
+ zstyle ':omz:plugins:nvm' lazy-cmd $NVM_LAZY_CMD
+ fi
+ echo "$reset_color"
+ unset used_vars NVM_AUTOLOAD NVM_LAZY NVM_LAZY_CMD
+fi
+
+if zstyle -t ':omz:plugins:nvm' lazy; then
+ # Call nvm when first using nvm, node, npm, pnpm, yarn or other commands in lazy-cmd
+ zstyle -a ':omz:plugins:nvm' lazy-cmd nvm_lazy_cmd
+ eval "
+ function nvm node npm pnpm yarn $nvm_lazy_cmd {
+ unfunction nvm node npm pnpm yarn $nvm_lazy_cmd
+ # Load nvm if it exists in \$NVM_DIR
+ [[ -f \"\$NVM_DIR/nvm.sh\" ]] && source \"\$NVM_DIR/nvm.sh\"
+ \"\$0\" \"\$@\"
+ }
+ "
+ unset nvm_lazy_cmd
elif [[ -f "$NVM_DIR/nvm.sh" ]]; then
# Load nvm if it exists in $NVM_DIR
source "$NVM_DIR/nvm.sh"
@@ -33,7 +60,7 @@ fi
# Autoload nvm when finding a .nvmrc file in the current directory
# Adapted from: https://github.com/nvm-sh/nvm#zsh
-if (( $+NVM_AUTOLOAD )); then
+if zstyle -t ':omz:plugins:nvm' autoload; then
load-nvmrc() {
local node_version="$(nvm version)"
local nvmrc_path="$(nvm_find_nvmrc)"
@@ -70,4 +97,4 @@ for nvm_completion in "$NVM_DIR/bash_completion" "$NVM_HOMEBREW/etc/bash_complet
fi
done
-unset NVM_HOMEBREW NVM_LAZY NVM_AUTOLOAD nvm_completion
+unset NVM_HOMEBREW nvm_completion